@@ -12,7 +12,7 @@ try:
 except:
     pass
 
-version = '0.111'
+version = '0.113'
 
 import re
 import tempfile
@@ -507,6 +507,7 @@ def txtread(path):
     elif 'gs://' in path:
         return gsTxtread(path)
     else:
+        path = os.path.expanduser(path)
         with open(path, 'r') as f:
             return f.read()
 
@@ -514,6 +515,7 @@ def txtwrite(path, txt):
     if 'gs://' in path:
         gsTxtwrite(path, txt)
     else:
+        path = os.path.expanduser(path)
         os.makedirs(os.path.dirname(path), exist_ok=True)
         with open(path, 'w') as f:
             return f.write(txt)
@@ -532,6 +534,7 @@ if is_testing():
 
 
 def yamlwrite(path, obj):
+    path = os.path.expanduser(path)
     txtwrite(path, yaml.dump(obj, sort_keys=False))
 
 
@@ -539,6 +542,7 @@ def yamlwrite(path, obj):
 
 
 def yamlread(path):
+    path = os.path.expanduser(path)
     return yaml.safe_load(txtread(path=path))
 
 
@@ -729,6 +733,7 @@ def pklwrite(path, obj):
     if 'gs://' in path:
         return gsPklWrite(path, obj)
     else:
+        path = os.path.expanduser(path)
         if len(os.path.dirname(path)) > 0:
             os.makedirs(os.path.dirname(path), exist_ok=True)
         with open(path, 'wb') as f:
@@ -742,6 +747,7 @@ def pklread(path):
     if 'gs://' in path:
         return gsPklRead(path)
     else:
+        path = os.path.expanduser(path)
         with open(path, 'rb') as f:
             return pickle.load(f)
 
@@ -757,6 +763,36 @@ if is_testing():
         print(pklread(pkl_path))
 
 
+# In[ ]:
+
+
+def pklappend(path, obj):
+    path = os.path.expanduser(path)
+    if len(os.path.dirname(path)) > 0:
+        os.makedirs(os.path.dirname(path), exist_ok=True)
+    with open(path, 'ab') as f:
+        return pickle.dump(obj, f, protocol=4)
+
+def pklreadall(path):
+    path = os.path.expanduser(path)
+    objects = []
+    with open(path, 'rb') as f:
+        try:
+            while True:
+                objects.append(pickle.load(f))
+        except EOFError:
+            pass
+    return objects
+
+if is_testing():
+    with tempfile.TemporaryDirectory() as dir_path:
+        pkl_path = os.path.join(dir_path, 'test.pkl')
+        
+        pklappend(pkl_path, {'testA':1})
+        pklappend(pkl_path, {'testB':2})
+        print(pklreadall(pkl_path))
+
+
 # # Images
 
 # In[ ]:
@@ -2007,5 +2043,5 @@ if is_testing():
 # In[ ]:
 
 
-
+0
 
